Changelog
==========

1.9.1 (2019-09-06)
------------------

- Fix TypeError: unhashable type: 'Entry'.


1.9 (2019-09-05)
----------------

- First release to PyPI.
- Unified three older scripts I had lying around with hardcoded configuration.
- Replaced hardcoded configuration with command-line arguments.
